# Generated by Django 3.0.8 on 2020-08-21 16:52

from django.db import migrations, models
import django.db.models.deletion
import modelcluster.fields
import uuid
import wagtail.core.blocks
import wagtail.core.fields
import wagtail_localize.test.models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtailcore", "0057_page_locale_fields_notnull"),
        ("wagtail_localize_test", "0002_nontranslatablesnippet"),
    ]

    operations = [
        migrations.CreateModel(
            name="TestGenerateTranslatableFieldsPage",
            fields=[
                (
                    "page_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="wagtailcore.Page",
                    ),
                ),
                ("test_charfield", models.CharField(blank=True, max_length=255)),
                (
                    "test_charfield_with_choices",
                    models.CharField(
                        blank=True, choices=[("a", "A"), ("b", "B")], max_length=255
                    ),
                ),
                ("test_textfield", models.TextField(blank=True)),
                ("test_emailfield", models.EmailField(blank=True, max_length=254)),
                ("test_slugfield", models.SlugField(blank=True)),
                ("test_urlfield", models.URLField(blank=True)),
                ("test_richtextfield", wagtail.core.fields.RichTextField(blank=True)),
                (
                    "test_streamfield",
                    wagtail.core.fields.StreamField(
                        [
                            (
                                "test_charblock",
                                wagtail.core.blocks.CharBlock(max_length=255),
                            ),
                            ("test_textblock", wagtail.core.blocks.TextBlock()),
                            ("test_emailblock", wagtail.core.blocks.EmailBlock()),
                            ("test_urlblock", wagtail.core.blocks.URLBlock()),
                            ("test_richtextblock", wagtail.core.blocks.RichTextBlock()),
                            ("test_rawhtmlblock", wagtail.core.blocks.RawHTMLBlock()),
                            (
                                "test_blockquoteblock",
                                wagtail.core.blocks.BlockQuoteBlock(),
                            ),
                            (
                                "test_structblock",
                                wagtail.core.blocks.StructBlock(
                                    [
                                        ("field_a", wagtail.core.blocks.TextBlock()),
                                        ("field_b", wagtail.core.blocks.TextBlock()),
                                    ]
                                ),
                            ),
                            (
                                "test_listblock",
                                wagtail.core.blocks.ListBlock(
                                    wagtail.core.blocks.TextBlock()
                                ),
                            ),
                            (
                                "test_nestedstreamblock",
                                wagtail.core.blocks.StreamBlock(
                                    [
                                        ("block_a", wagtail.core.blocks.TextBlock()),
                                        ("block_b", wagtail.core.blocks.TextBlock()),
                                    ]
                                ),
                            ),
                            (
                                "test_customstructblock",
                                wagtail.core.blocks.StructBlock(
                                    [
                                        ("field_a", wagtail.core.blocks.TextBlock()),
                                        ("field_b", wagtail.core.blocks.TextBlock()),
                                    ]
                                ),
                            ),
                        ],
                        blank=True,
                    ),
                ),
                (
                    "test_customfield",
                    wagtail_localize.test.models.TestCustomField(blank=True),
                ),
                (
                    "test_nontranslatablesnippet",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to="wagtail_localize_test.NonTranslatableSnippet",
                    ),
                ),
                (
                    "test_snippet",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="wagtail_localize_test.TestSnippet",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("wagtailcore.page",),
        ),
        migrations.CreateModel(
            name="NonTranslatableChildObject",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "sort_order",
                    models.IntegerField(blank=True, editable=False, null=True),
                ),
                ("field", models.TextField()),
                (
                    "page",
                    modelcluster.fields.ParentalKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="test_nontranslatable_childobjects",
                        to="wagtail_localize_test.TestPage",
                    ),
                ),
            ],
            options={
                "ordering": ["sort_order"],
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="TranslatableChildObject",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "translation_key",
                    models.UUIDField(default=uuid.uuid4, editable=False),
                ),
                (
                    "sort_order",
                    models.IntegerField(blank=True, editable=False, null=True),
                ),
                ("field", models.TextField()),
                (
                    "locale",
                    models.ForeignKey(
                        editable=False,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="wagtailcore.Locale",
                    ),
                ),
                (
                    "page",
                    modelcluster.fields.ParentalKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="test_translatable_childobjects",
                        to="wagtail_localize_test.TestPage",
                    ),
                ),
            ],
            options={
                "ordering": ["sort_order"],
                "abstract": False,
                "unique_together": {("translation_key", "locale")},
            },
        ),
    ]



# Generated by Django 3.0.5 on 2021-10-21 13:40

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        (
            "wagtail_localize_test",
            "0016_testpage_test_not_overridable_synchronized_textfield",
        ),
    ]

    operations = [
        migrations.CreateModel(
            name="TestWithTranslationModeDisabledPage",
            fields=[
                (
                    "page_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="wagtailcore.Page",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("wagtailcore.page",),
        ),
        migrations.CreateModel(
            name="TestWithTranslationModeEnabledPage",
            fields=[
                (
                    "page_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="wagtailcore.Page",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("wagtailcore.page",),
        ),
    ]



# Generated by Django 3.2.4 on 2021-06-29 15:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtail_localize_test", "0014_auto_20210217_0924"),
    ]

    operations = [
        migrations.AddField(
            model_name="testsnippet",
            name="small_charfield",
            field=models.CharField(blank=True, max_length=10),
        ),
    ]



# Generated by Django 3.1.2 on 2020-10-20 14:10

from django.db import migrations, models
import django.db.models.deletion
import wagtail.core.blocks
import wagtail.core.fields
import wagtail.documents.blocks
import wagtail.images.blocks
import wagtail.snippets.blocks
import wagtail_localize.test.models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildocs", "0010_document_file_hash"),
        ("wagtailimages", "0022_uploadedimage"),
        ("wagtail_localize_test", "0006_auto_20201006_1338"),
    ]

    operations = [
        migrations.AddField(
            model_name="testpage",
            name="test_synchronized_document",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="wagtaildocs.document",
            ),
        ),
        migrations.AddField(
            model_name="testpage",
            name="test_synchronized_image",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="wagtailimages.image",
            ),
        ),
        migrations.AlterField(
            model_name="testgeneratetranslatablefieldspage",
            name="test_streamfield",
            field=wagtail.core.fields.StreamField(
                [
                    ("test_charblock", wagtail.core.blocks.CharBlock(max_length=255)),
                    (
                        "test_textblock",
                        wagtail.core.blocks.TextBlock(label="text block"),
                    ),
                    ("test_emailblock", wagtail.core.blocks.EmailBlock()),
                    ("test_urlblock", wagtail.core.blocks.URLBlock()),
                    ("test_richtextblock", wagtail.core.blocks.RichTextBlock()),
                    ("test_rawhtmlblock", wagtail.core.blocks.RawHTMLBlock()),
                    ("test_blockquoteblock", wagtail.core.blocks.BlockQuoteBlock()),
                    (
                        "test_structblock",
                        wagtail.core.blocks.StructBlock(
                            [
                                ("field_a", wagtail.core.blocks.TextBlock()),
                                ("field_b", wagtail.core.blocks.TextBlock()),
                            ]
                        ),
                    ),
                    (
                        "test_listblock",
                        wagtail.core.blocks.ListBlock(wagtail.core.blocks.TextBlock()),
                    ),
                    (
                        "test_nestedstreamblock",
                        wagtail.core.blocks.StreamBlock(
                            [
                                ("block_a", wagtail.core.blocks.TextBlock()),
                                ("block_b", wagtail.core.blocks.TextBlock()),
                            ]
                        ),
                    ),
                    (
                        "test_customstructblock",
                        wagtail.core.blocks.StructBlock(
                            [
                                ("field_a", wagtail.core.blocks.TextBlock()),
                                ("field_b", wagtail.core.blocks.TextBlock()),
                            ]
                        ),
                    ),
                    (
                        "test_customblockwithoutextractmethod",
                        wagtail_localize.test.models.CustomBlockWithoutExtractMethod(),
                    ),
                    ("test_pagechooserblock", wagtail.core.blocks.PageChooserBlock()),
                    (
                        "test_imagechooserblock",
                        wagtail.images.blocks.ImageChooserBlock(),
                    ),
                    (
                        "test_documentchooserblock",
                        wagtail.documents.blocks.DocumentChooserBlock(),
                    ),
                    (
                        "test_snippetchooserblock",
                        wagtail.snippets.blocks.SnippetChooserBlock(
                            wagtail_localize.test.models.TestSnippet
                        ),
                    ),
                ],
                blank=True,
            ),
        ),
        migrations.AlterField(
            model_name="testpage",
            name="test_streamfield",
            field=wagtail.core.fields.StreamField(
                [
                    ("test_charblock", wagtail.core.blocks.CharBlock(max_length=255)),
                    (
                        "test_textblock",
                        wagtail.core.blocks.TextBlock(label="text block"),
                    ),
                    ("test_emailblock", wagtail.core.blocks.EmailBlock()),
                    ("test_urlblock", wagtail.core.blocks.URLBlock()),
                    ("test_richtextblock", wagtail.core.blocks.RichTextBlock()),
                    ("test_rawhtmlblock", wagtail.core.blocks.RawHTMLBlock()),
                    ("test_blockquoteblock", wagtail.core.blocks.BlockQuoteBlock()),
                    (
                        "test_structblock",
                        wagtail.core.blocks.StructBlock(
                            [
                                ("field_a", wagtail.core.blocks.TextBlock()),
                                ("field_b", wagtail.core.blocks.TextBlock()),
                            ]
                        ),
                    ),
                    (
                        "test_listblock",
                        wagtail.core.blocks.ListBlock(wagtail.core.blocks.TextBlock()),
                    ),
                    (
                        "test_nestedstreamblock",
                        wagtail.core.blocks.StreamBlock(
                            [
                                ("block_a", wagtail.core.blocks.TextBlock()),
                                ("block_b", wagtail.core.blocks.TextBlock()),
                            ]
                        ),
                    ),
                    (
                        "test_customstructblock",
                        wagtail.core.blocks.StructBlock(
                            [
                                ("field_a", wagtail.core.blocks.TextBlock()),
                                ("field_b", wagtail.core.blocks.TextBlock()),
                            ]
                        ),
                    ),
                    (
                        "test_customblockwithoutextractmethod",
                        wagtail_localize.test.models.CustomBlockWithoutExtractMethod(),
                    ),
                    ("test_pagechooserblock", wagtail.core.blocks.PageChooserBlock()),
                    (
                        "test_imagechooserblock",
                        wagtail.images.blocks.ImageChooserBlock(),
                    ),
                    (
                        "test_documentchooserblock",
                        wagtail.documents.blocks.DocumentChooserBlock(),
                    ),
                    (
                        "test_snippetchooserblock",
                        wagtail.snippets.blocks.SnippetChooserBlock(
                            wagtail_localize.test.models.TestSnippet
                        ),
                    ),
                ],
                blank=True,
            ),
        ),
        migrations.AlterField(
            model_name="testpage",
            name="test_synchronized_streamfield",
            field=wagtail.core.fields.StreamField(
                [
                    ("test_charblock", wagtail.core.blocks.CharBlock(max_length=255)),
                    (
                        "test_textblock",
                        wagtail.core.blocks.TextBlock(label="text block"),
                    ),
                    ("test_emailblock", wagtail.core.blocks.EmailBlock()),
                    ("test_urlblock", wagtail.core.blocks.URLBlock()),
                    ("test_richtextblock", wagtail.core.blocks.RichTextBlock()),
                    ("test_rawhtmlblock", wagtail.core.blocks.RawHTMLBlock()),
                    ("test_blockquoteblock", wagtail.core.blocks.BlockQuoteBlock()),
                    (
                        "test_structblock",
                        wagtail.core.blocks.StructBlock(
                            [
                                ("field_a", wagtail.core.blocks.TextBlock()),
                                ("field_b", wagtail.core.blocks.TextBlock()),
                            ]
                        ),
                    ),
                    (
                        "test_listblock",
                        wagtail.core.blocks.ListBlock(wagtail.core.blocks.TextBlock()),
                    ),
                    (
                        "test_nestedstreamblock",
                        wagtail.core.blocks.StreamBlock(
                            [
                                ("block_a", wagtail.core.blocks.TextBlock()),
                                ("block_b", wagtail.core.blocks.TextBlock()),
                            ]
                        ),
                    ),
                    (
                        "test_customstructblock",
                        wagtail.core.blocks.StructBlock(
                            [
                                ("field_a", wagtail.core.blocks.TextBlock()),
                                ("field_b", wagtail.core.blocks.TextBlock()),
                            ]
                        ),
                    ),
                    (
                        "test_customblockwithoutextractmethod",
                        wagtail_localize.test.models.CustomBlockWithoutExtractMethod(),
                    ),
                    ("test_pagechooserblock", wagtail.core.blocks.PageChooserBlock()),
                    (
                        "test_imagechooserblock",
                        wagtail.images.blocks.ImageChooserBlock(),
                    ),
                    (
                        "test_documentchooserblock",
                        wagtail.documents.blocks.DocumentChooserBlock(),
                    ),
                    (
                        "test_snippetchooserblock",
                        wagtail.snippets.blocks.SnippetChooserBlock(
                            wagtail_localize.test.models.TestSnippet
                        ),
                    ),
                ],
                blank=True,
            ),
        ),
    ]



from django import VERSION as DJANGO_VERSION


if DJANGO_VERSION >= (3, 2):
    # The declaration is only needed for older Django versions
    pass
else:
    default_app_config = "wagtail_localize.test.apps.WagtailLocalizeTestAppConfig"
